class Admin::AcademicAdvisingsController < OrbitMemberController
  layout "member_plugin"
  include Admin::AcademicAdvisingsHelper

  before_action :set_academic_advising, only: [:show, :edit , :update, :destroy]
  before_action :set_plugin
  before_action :get_settings,:only => [:new, :edit, :setting]

  before_action :need_access_right
  before_action :allow_admin_only, :only => [:index, :setting]

  def index
    @academic_advisings = Advising.order_by(:year=>'desc').page(params[:page]).per(10)
  end

  def new
    @member = MemberProfile.find_by(:uid=>params['uid']) rescue nil
    @academic_advising = Advising.new

    if params[:desktop]
      render :layout => false
    end
  end

  def analysis_report
    role = params[:role_id]
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    graph_by = params[:graph_by]

    @data = get_chart_data(year_start,year_end,role,params[:graph_by])
    
    render :layout => false
  end

  def download_excel
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    @data = get_data_for_excel(year_start,year_end)
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="academic_advisings.xlsx"'
      }
    end
  end

  def create

    if !academic_advising_params['member_profile_id'].blank?

      @member = MemberProfile.find(academic_advising_params['member_profile_id']) rescue nil
      @academic_advising = Advising.new(academic_advising_params)
      @academic_advising.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      else
        redirect_to params['referer_url']
      end

    elsif !params[:author_members].blank?

      params[:author_members].each do |author_member|

        academic_advising_params['member_profile_id'] = author_member
        @academic_advising = Advising.new(academic_advising_params)
        @academic_advising.save

        if params[:desktop] == "true"
          render json: {"data" => get_paper_list}.to_json
        end

      end

      redirect_to params['referer_url']

    else

      academic_advising_params['member_profile_id'] = User.find(current_user.id).member_profile_id

      @academic_advising = Advising.new(academic_advising_params)
      @academic_advising.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      end

      redirect_to params['referer_url']

    end
    
  end

  def edit
    @member = @academic_advising.member_profile rescue nil
    if params[:desktop]
      render :layout => false
    end
  end

  def update
    @member = @academic_advising.member_profile rescue nil
    @academic_advising.update_attributes(academic_advising_params)
    @academic_advising.save
    if params[:desktop] == "true"
      render json: {"data" => get_paper_list}.to_json
    else
      redirect_to params['referer_url']
    end
  end

  def destroy
    @academic_advising.destroy
    respond_to do |format|
      format.html { redirect_to(admin_academic_advising_url) }
      # format.xml { head :ok }
      format.js
      format.json {render json: {"success" => true}}
    end
  end

  def toggle_hide
    if params[:ids]
      @academic_advisings = Advising.any_in(_id: params[:ids])

      @academic_advisings.each do |academic_advising|
        academic_advising.is_hidden = params[:disable]
        academic_advising.save
      end
    end

    render json: {"success"=>true}
  end

  def excel_format
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="academic_advising_format.xlsx"'
      }
    end
  end

   def import_from_excel
    workbook = RubyXL::Parser.parse(params["import_file"].tempfile)
    sheet = workbook[0]
    if sheet.count <= 503
      sheet.each_with_index do |row, i|
        next if i < 3
        user = User.where(:user_name => row.cells[0].value).first rescue nil
        if !user.nil?
          mp = user.member_profile
          import_this_academic_advising(row,mp)
        end
      end
      redirect_to admin_academic_advisings_url
    else
      redirect_to admin_academic_advisings_url(:error => "1")
    end
  end

  def setting
  end

  def frontend_setting
    @member = MemberProfile.find_by(:uid=>params['uid']) rescue nil
    @intro = AdvisingIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? AdvisingIntro.new({:member_profile_id=>@member.id}) : @intro
  end

  def update_frontend_setting
    @member = MemberProfile.find(intro_params['member_profile_id']) rescue nil
    @intro = AdvisingIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? AdvisingIntro.new({:member_profile_id=>@member.id}) : @intro
    @intro.update_attributes(intro_params)
    @intro.save
    redirect_to URI.encode('/admin/members/'+@member.to_param+'/AcademicAdvising')
  end

  def get_settings
    @academic_advising_types = AdvisingType.all
  end

  def set_plugin
    @plugin = OrbitApp::Plugin::Registration.all.select{|plugin| plugin.app_name.eql? 'Advising'}.first
  end

  private

   def set_academic_advising
    path = request.path.split('/')
    if path.last.include? '-'
      uid = path[-1].split("-").last
      uid = uid.split("?").first
    else
      uid = path[-2].split("-").last
      uid = uid.split("?").first
    end
     @academic_advising = Advising.find_by(:uid => uid) rescue Advising.find(params[:id])
  end

  def academic_advising_params
    params.require(:advising).permit! rescue nil
  end

  def intro_params
    params.require(:advising_intro).permit! rescue nil
  end
end