class Advising
  include Mongoid::Document
  include Mongoid::Timestamps
  include OrbitModel::Status
  include Slug
  
  belongs_to :advising_type
  belongs_to :member_profile
  
  field :year, type: Integer
  field :award_name, localize: true
  field :awarding_unit, localize: true
  field :award_date, type: DateTime
  field :language
  field :keywords
  field :url
  field :note
  field :rss2_id
  field :requirement, localize: true
  field :create_user_id, :type => BSON::ObjectId
  field :update_user_id, :type => BSON::ObjectId
  field :advising_student_ids, :type => Array, default: []
  # paginates_per 10

  before_validation :add_http

  scope :sort_for_frontend, ->{ where(:is_hidden=>false).order_by(:year => "desc",:award_date => "desc") }
  def display_year
    ((self.year.present? && I18n.locale.to_s == "zh_tw") ? (self.year > 1911 ? (self.year - 1911) : self.year ) : self.year)
  end
  def display_advising_type
    (self.advising_type ? self.advising_type.title : "")
  end
  def slug_title
    self.award_name+' '+self.awarding_unit rescue ""
  end
  def advising_students
    MemberProfile.where(:id.in => self.advising_student_ids)
  end
  def get_plugin_data(fields_to_show)
    plugin_datas = []
    fields_to_show.each do |field|
      plugin_data = self.get_plugin_field_data(field) rescue nil
      next if plugin_data.blank? or plugin_data['value'].blank?
      plugin_datas << plugin_data
    end
    plugin_datas
  end
  def advising_students_front_data
    self.advising_students.collect{|member| "<a href='#{OrbitHelper.url_to_plugin_show(member.to_param,'member')}' title='#{member.name}'>#{member.name}</a>"}.join('、')
  end
  def self.get_plugin_datas_to_member(datas)
    page = Page.where(:module => "academic_advising").first rescue nil
    
    if !page.nil? && !page.custom_array_field.blank?
      fields_to_show = page.custom_array_field
    else
      fields_to_show = [
        "year",
        "academic_advising_type",
        "award_name",
        "awarding_unit",
        "advising_students"
      ]
    end

    fields_to_remove = []

    pd_title = []
    fields_to_show.each do |t|
      if (self.fields[t].type.to_s == "String" || self.fields[t].type.to_s == "Object" rescue false)
        fields_to_remove << t if (datas.where(t.to_sym.ne => nil, t.to_sym.ne => "").count == 0 rescue false)
      elsif t=='advising_students'
        fields_to_remove << t if (datas.where(:advising_student_ids.ne => []).count == 0 rescue false)
      elsif t == "academic_advising_type"
        fields_to_remove << t if (datas.where(:advising_type.ne => nil).count == 0 rescue false)
      else
        fields_to_remove << t if (datas.where(t.to_sym.ne => nil).count == 0 rescue false)
      end
      pd_title <<  {
          "plugin_data_title" => I18n.t("academic_advising.#{t}")
        } if !fields_to_remove.include?(t)
    end
    fields_to_show = fields_to_show - fields_to_remove

    plugin_datas = datas.sort_for_frontend.collect.with_index do |p,index|
      pd_data = []
      fields_to_show.collect do |t|
        if t == "award_name"
          pd_data << { "data_title" => "<a href='#{OrbitHelper.url_to_plugin_show(p.to_param,'academic_advising')}' title='#{p.send(t)}' target='_blank'>#{p.send(t)}</a>" }
        elsif t == "academic_advising_type"
          pd_data << {"data_title" => p.display_advising_type}
        elsif t == "award_date"
          pd_data << {"data_title" => (p.send(t).strftime("%Y/%m/%d") rescue "")}
        elsif t == "advising_students"
          pd_data << {"data_title" => p.advising_students_front_data}
        elsif t == "year"
          pd_data << { "data_title" => p.display_year }
        else
          pd_data << { "data_title" => p.send(t) }
        end
      end
      {
        "pd_datas" => pd_data,
        "type-sort" => (p.academic_advising_type.sort_position.to_i rescue 1000),
        "sort-index" => index
      }

    end
    plugin_datas = plugin_datas.sort_by{|pd| [pd["type-sort"], pd["sort-index"]]}
    return [pd_title,plugin_datas]

  end

  def get_plugin_field_data(field)
    case field
    when "academic_advisingee"
      path = OrbitHelper.url_to_plugin_show(self.member_profile.to_param, 'member') rescue '#'
      value = "<a href='#{path}'>" + self.member_profile.name + "</a>"
    when "language"
      value = I18n.t(self.language) rescue ""
    when "academic_advising_type"
      value = self.display_advising_type
    when "award_date"
      value = self.award_date.strftime("%Y/%m/%d") rescue ""
    when "advising_students"
      value = self.advising_students_front_data
    when "year"
      value = self.display_year
    else
      value = self.send(field) rescue ""
    end

    value = (value =~ /\A#{URI::regexp(['http', 'https'])}\z/) ? "<a href='#{value}' target='blank'>#{value}</a>" : value
    
    {
      "key"=>field,
      "title_class"=>"academic_advising-#{field.gsub('_','-')}-field",
      "value_class"=>"academic_advising-#{field.gsub('_','-')}-value",
      "title"=>I18n.t('academic_advising.'+field),
      "value"=>value
    }
  end

  protected

  def add_http
    unless self.url.blank? || self.url[/^http:\/\//] || self.url[/^https:\/\//]
      self.url = 'http://' + self.url
    end
  end
  
end
